@@ -22,8 +22,12 @@ def check_key_decorator(func):
 class OpenAIEmbeddingBlock(EmbeddingBlock):
     open_ai_key: Optional[str] = None
 
-    def __init__(self, open_ai_key: str) -> None:
+    def __init__(self, open_ai_key: str, use_helicone: bool = False) -> None:
         self.open_ai_key = open_ai_key
+        if use_helicone:
+            self.base_url = "https://oai.hconeai.com/v1"
+        else:
+            self.base_url = "https://api.openai.com/v1"
 
     @check_key_decorator
     def embed_text(self, text: str) -> List[int]:
@@ -35,5 +39,5 @@ class OpenAIEmbeddingBlock(EmbeddingBlock):
             "input": text,
             "model": "text-embedding-ada-002",
         }
-        response = requests.post("https://api.openai.com/v1/embeddings", headers=headers, json=json_data)
+        response = requests.post(f"{self.base_url}/embeddings", headers=headers, json=json_data)
         return response.json()["data"][0]["embedding"]
